@@ -1,8 +1,3 @@
-"""
-Author: barbacbd
-Date:   4/20/2020
-"""
-
 from ..error import NauticalError
 from math import radians, sin, cos, atan2, sqrt
 from .point import Point
@@ -12,7 +7,7 @@ _EARTH_RADIUS_METERS = 6372800
 
 def haversine(p1: Point, p2: Point) -> float:
     """
-    Find the distance between two points using the Haversine methodology
+    :return: Find the distance between two points using the Haversine methodology
     """
     lat1 = radians(p1.latitude)
     lat2 = radians(p2.latitude)
@@ -26,12 +21,16 @@ def haversine(p1: Point, p2: Point) -> float:
 
 
 def in_range_ll(lat1_deg: float, lon1_deg: float, lat2_deg: float, lon2_deg: float, distance_m) -> bool:
-    # return whether or on the lat, lon points are within a range of each other
+    """
+    :return: whether or on the lat, lon points are within a range of each other
+    """
     return in_range(Point(lat1_deg, lon1_deg), Point(lat2_deg, lon2_deg), distance_m)
 
 
 def in_range(p1: Point, p2: Point, distance_m) -> bool:
-    # return whether or not these two points are within a range of each other
+    """
+    :return: whether or not these two points are within a range of each other
+    """
     return haversine(p1, p2) <= distance_m
 
 
@@ -39,6 +38,7 @@ def area_converter(area: [Point]) -> [Point]:
     """
     Pass in a list of points, determine the maximum and minimum latitude and longitude
     values, create a square (4 points) from the list.
+
     :param area: original list of points
     :return: list of Points
     """
@@ -61,6 +61,7 @@ def in_area(p: Point, area: [Point]) -> bool:
     """
     Determine if point p is in the area. NOTE: the user should pass the original
     list of points through the area_converter. This will provide an approximate area.
+
     :param p: Point to determine if it is in the area
     :param area: 2 point area min, min -> max, max
     :return: true if it is in the area false otherwise
